@@ -94,7 +94,7 @@ public:
 	QString presetFile(const QString& sPreset);
 	void setPresetFile(const QString& sPreset, const QString& sPresetFile);
 	void removePreset(const QString& sPreset);
-	QStringList presetList();
+	const QStringList& presetList();
 
 	// Programs utility methods.
 	void loadPrograms(synthv1_programs *pPrograms);
@@ -127,6 +127,9 @@ protected:
 
 private:
 
+	// The presets list cache.
+	QStringList m_presetList;
+
 	// The singleton instance.
 	static synthv1_config *g_pSettings;
 };
