@@ -1,7 +1,7 @@
 // synthv1_jack.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -694,6 +694,8 @@ void synthv1_jack::shutdown_close (void)
 #endif
 #endif
 
+#include <QTimer>
+
 #ifdef CONFIG_NSM
 #include "synthv1_nsm.h"
 #endif
@@ -1020,6 +1022,9 @@ bool synthv1_jack_application::setup (void)
 	if (m_pWidget)
 		m_pWidget->show();
 
+	// Start watchdog timer...
+	watchdog_start();
+
 	return true;
 }
 
@@ -1062,19 +1067,23 @@ void synthv1_jack_application::openSession (void)
 	if (!dir.exists())
 		dir.mkpath(path_name);
 
+	bool bOpen = false;
+
 	QFileInfo fi(path_name, "session." SYNTHV1_TITLE);
 	if (!fi.exists())
 		fi.setFile(path_name, display_name + '.' + SYNTHV1_TITLE);
 	if (fi.exists()) {
 		const QString& sFilename = fi.absoluteFilePath();
 		if (m_pWidget) {
-			m_pWidget->loadPreset(sFilename);
+			bOpen = m_pWidget->loadPreset(sFilename);
 		} else {
-			synthv1_param::loadPreset(m_pSynth, sFilename);
+			bOpen = synthv1_param::loadPreset(m_pSynth, sFilename);
 		}
 	}
 
-	m_pNsmClient->open_reply();
+	m_pNsmClient->open_reply(bOpen
+		? synthv1_nsm::ERR_OK
+		: synthv1_nsm::ERR_GENERAL);
 	m_pNsmClient->dirty(false);
 
 	if (m_pWidget)
@@ -1102,9 +1111,12 @@ void synthv1_jack_application::saveSession (void)
 //	const QFileInfo fi(path_name, display_name + '.' + SYNTHV1_TITLE);
 	const QFileInfo fi(path_name, "session." SYNTHV1_TITLE);
 
-	synthv1_param::savePreset(m_pSynth, fi.absoluteFilePath(), true);
+	const bool bSave
+		= synthv1_param::savePreset(m_pSynth, fi.absoluteFilePath(), true);
 
-	m_pNsmClient->save_reply();
+	m_pNsmClient->save_reply(bSave
+		? synthv1_nsm::ERR_OK
+		: synthv1_nsm::ERR_GENERAL);
 	m_pNsmClient->dirty(false);
 }
 
@@ -1170,6 +1182,29 @@ void synthv1_jack_application::handle_sigterm (void)
 #endif	// HAVE_SIGNAL_H
 
 
+// Simple watchdog (3 minute cycle).
+void synthv1_jack_application::watchdog_slot (void)
+{
+	if (m_pSynth && m_pSynth->client() == nullptr) {
+		const QByteArray aClientName
+			= m_sClientName.toLocal8Bit();
+		const char *client_name
+			= aClientName.constData();
+		m_pSynth->open(client_name);
+		m_pSynth->activate();
+	}
+
+	watchdog_start();
+}
+
+
+void synthv1_jack_application::watchdog_start (void)
+{
+	if (g_pInstance)
+		QTimer::singleShot(60000, this, SLOT(watchdog_slot()));
+}
+
+
 // JACK shutdown handlers.
 void synthv1_jack_application::shutdown (void)
 {
@@ -1179,16 +1214,18 @@ void synthv1_jack_application::shutdown (void)
 
 void synthv1_jack_application::shutdown_slot (void)
 {
-	bool bQuit = true;
-
 	if (m_pSynth)
 		m_pSynth->shutdown_close();
 
+#if 0//Don't quit anymore; let watchdog handle auto re-activation...
+	bool bQuit = true;
+
 	if (m_pWidget)
 		bQuit = m_pWidget->queryClose();
 
 	if (m_pApp && bQuit)
 		m_pApp->quit();
+#endif
 }
 
 
