@@ -1,7 +1,7 @@
 // synthv1widget.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -1333,7 +1333,7 @@ void synthv1widget::newPreset (void)
 
 
 // Preset file I/O slots.
-void synthv1widget::loadPreset ( const QString& sFilename )
+bool synthv1widget::loadPreset ( const QString& sFilename )
 {
 #ifdef CONFIG_DEBUG
 	qDebug("synthv1widget::loadPreset(\"%s\")", sFilename.toUtf8().constData());
@@ -1342,29 +1342,41 @@ void synthv1widget::loadPreset ( const QString& sFilename )
 	resetParamKnobs();
 	resetParamValues();
 
+	bool bLoad = false;
+
 	synthv1_ui *pSynthUi = ui_instance();
 	if (pSynthUi)
-		pSynthUi->loadPreset(sFilename);
+		bLoad = pSynthUi->loadPreset(sFilename);
 
-	updateLoadPreset(QFileInfo(sFilename).completeBaseName());
+	if (bLoad)
+		updateLoadPreset(QFileInfo(sFilename).completeBaseName());
+	else
+		updateDirtyPreset(true);
+
+	return bLoad;
 }
 
 
-void synthv1widget::savePreset ( const QString& sFilename )
+bool synthv1widget::savePreset ( const QString& sFilename )
 {
 #ifdef CONFIG_DEBUG
 	qDebug("synthv1widget::savePreset(\"%s\")", sFilename.toUtf8().constData());
 #endif
 
+	bool bSave = false;
+
 	synthv1_ui *pSynthUi = ui_instance();
 	if (pSynthUi)
-		pSynthUi->savePreset(sFilename);
+		bSave = pSynthUi->savePreset(sFilename);
 
-	const QString& sPreset
-		= QFileInfo(sFilename).completeBaseName();
+	if (bSave) {
+		const QString& sPreset
+			= QFileInfo(sFilename).completeBaseName();
+		m_ui.StatusBar->showMessage(tr("Save preset: %1").arg(sPreset), 5000);
+	}
+	updateDirtyPreset(!bSave);
 
-	m_ui.StatusBar->showMessage(tr("Save preset: %1").arg(sPreset), 5000);
-	updateDirtyPreset(false);
+	return bSave;
 }
 
 
@@ -1489,10 +1501,8 @@ void synthv1widget::midiInLedTimeout (void)
 void synthv1widget::helpConfigure (void)
 {
 	synthv1_ui *pSynthUi = ui_instance();
-	if (pSynthUi == nullptr)
-		return;
-
-	synthv1widget_config(pSynthUi, this).exec();
+	if (pSynthUi)
+		synthv1widget_config(this, pSynthUi).exec();
 }
 
 
@@ -1519,15 +1529,15 @@ void synthv1widget::helpAbout (void)
 	list << tr("LV2 plug-in build disabled.");
 #endif
 
-	QString sText = "<p>\n";
-	sText += "<b>" SYNTHV1_TITLE "</b> - " + tr(SYNTHV1_SUBTITLE) + "<br />\n";
+	QString sText = "<h1>" SYNTHV1_TITLE "</h1>\n";
+	sText += "<p>" + tr(SYNTHV1_SUBTITLE) + "<br />\n";
 	sText += "<br />\n";
 	sText += tr("Version") + ": <b>" CONFIG_BUILD_VERSION "</b><br />\n";
 //	sText += "<small>" + tr("Build") + ": " CONFIG_BUILD_DATE "</small><br />\n";
 	if (!list.isEmpty()) {
 		sText += "<small><font color=\"red\">";
 		sText += list.join("<br />\n");
-		sText += "</font></small><br />\n";
+		sText += "</font></small>\n";
 	}
 	sText += "<br />\n";
 	sText += tr("Using: Qt %1").arg(qVersion());
