@@ -1,7 +1,7 @@
 // synthv1widget_config.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -55,7 +55,7 @@ static const char *g_pszDefName = QT_TRANSLATE_NOOP("synthv1widget_config", "(de
 
 // ctor.
 synthv1widget_config::synthv1widget_config (
-	synthv1_ui *pSynthUi, QWidget *pParent )
+	synthv1widget *pParent, synthv1_ui *pSynthUi )
 	: QDialog(pParent), p_ui(new Ui::synthv1widget_config), m_ui(*p_ui),
 		m_pSynthUi(pSynthUi)
 {
@@ -81,6 +81,11 @@ synthv1widget_config::synthv1widget_config (
 	m_iDirtyPrograms = 0;
 	m_iDirtyOptions  = 0;
 
+	// Whether presets exist...
+	m_bPresets = false;
+
+	m_iLoadPreset = 0;
+
 	// Setup options...
 	synthv1_config *pConfig = synthv1_config::getInstance();
 	if (pConfig && m_pSynthUi) {
@@ -103,9 +108,10 @@ synthv1widget_config::synthv1widget_config (
 		// Load programs database...
 		synthv1_programs *pPrograms = m_pSynthUi->programs();
 		if (pPrograms) {
+			m_bPresets = !pConfig->presetList().isEmpty();
 			m_ui.ProgramsTreeWidget->loadPrograms(pPrograms);
-			m_ui.ProgramsEnabledCheckBox->setEnabled(bPlugin);
-			m_ui.ProgramsPreviewCheckBox->setEnabled(!bPlugin);
+			m_ui.ProgramsEnabledCheckBox->setEnabled(bPlugin && m_bPresets);
+			m_ui.ProgramsPreviewCheckBox->setEnabled(!bPlugin && m_bPresets);
 			m_ui.ProgramsEnabledCheckBox->setChecked(pPrograms->enabled());
 		}
 		// Initialize conveniency options...
@@ -446,11 +452,8 @@ void synthv1widget_config::programsChanged (void)
 
 void synthv1widget_config::programsActivated (void)
 {
-	if (m_pSynthUi) {
-		synthv1_programs *pPrograms = m_pSynthUi->programs();
-		if (m_ui.ProgramsPreviewCheckBox->isChecked() && pPrograms)
-			m_ui.ProgramsTreeWidget->selectProgram(pPrograms);
-	}
+	if (m_ui.ProgramsPreviewCheckBox->isChecked())
+		loadPreset(m_ui.ProgramsTreeWidget->currentProgramName());
 
 	stabilize();
 }
@@ -643,7 +646,7 @@ void synthv1widget_config::stabilize (void)
 	m_ui.ControlsDeleteToolButton->setEnabled(bEnabled);
 
 	pItem = m_ui.ProgramsTreeWidget->currentItem();
-	bEnabled = (m_pSynthUi && m_pSynthUi->programs() != nullptr);
+	bEnabled = (m_pSynthUi && m_pSynthUi->programs() != nullptr && m_bPresets);
 	m_ui.ProgramsPreviewCheckBox->setEnabled(
 		bEnabled && m_ui.ProgramsEnabledCheckBox->isChecked());
 	m_ui.ProgramsAddBankToolButton->setEnabled(bEnabled);
@@ -670,7 +673,8 @@ void synthv1widget_config::stabilize (void)
 		= (m_iDirtyTuning   > 0
 		|| m_iDirtyControls > 0
 		|| m_iDirtyPrograms > 0
-		|| m_iDirtyOptions  > 0);
+		|| m_iDirtyOptions  > 0
+		|| m_iLoadPreset    > 0);
 	m_ui.DialogButtonBox->button(QDialogButtonBox::Ok)->setEnabled(bValid);
 }
 
@@ -800,7 +804,8 @@ void synthv1widget_config::reject (void)
 	if (m_iDirtyTuning   > 0 ||
 		m_iDirtyControls > 0 ||
 		m_iDirtyPrograms > 0 ||
-		m_iDirtyOptions  > 0) {
+		m_iDirtyOptions  > 0 ||
+		m_iLoadPreset    > 0) {
 		QMessageBox::StandardButtons buttons
 			= QMessageBox::Discard | QMessageBox::Cancel;
 		if (m_ui.DialogButtonBox->button(QDialogButtonBox::Ok)->isEnabled())
@@ -815,11 +820,14 @@ void synthv1widget_config::reject (void)
 			return;
 		case QMessageBox::Discard:
 			break;
-		default:    // Cancel.
+		default: // Cancel.
 			bReject = false;
 		}
 	}
 
+	if (bReject && m_iLoadPreset > 0)
+		loadPreset(m_sSavePreset);
+
 	if (bReject)
 		QDialog::reject();
 }
@@ -984,4 +992,26 @@ QString synthv1widget_config::comboBoxCurrentItem ( QComboBox *pComboBox )
 }
 
 
+// Programs/preset preview stuff...
+void synthv1widget_config::loadPreset ( const QString& sPreset )
+{
+	synthv1_config *pConfig = synthv1_config::getInstance();
+	if (pConfig == nullptr)
+		return;
+
+	const QString& sPresetFile
+		= pConfig->presetFile(sPreset);
+	if (sPresetFile.isEmpty())
+		return;
+
+	synthv1widget *pParentWidget
+		= qobject_cast<synthv1widget *> (parentWidget());
+	if (pParentWidget && pParentWidget->loadPreset(sPresetFile)) {
+		if (++m_iLoadPreset == 1)
+			m_sSavePreset = pConfig->sPreset;
+		pConfig->sPreset = sPreset;
+	}
+}
+
+
 // end of synthv1widget_config.cpp
